Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(394)

Unified Diff: net/quic/quic_connection.h

Issue 413573003: Allow QuicConnection to own its QuicPacketWriter (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@change_BBR_sender_71436337
Patch Set: minor cleanup Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/quic/quic_connection.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_connection.h
diff --git a/net/quic/quic_connection.h b/net/quic/quic_connection.h
index 5bed086017795f183c1a2824bc7c309eaa204d31..a7e8a7e0f89c6cd19ec720023e10117046bfff71 100644
--- a/net/quic/quic_connection.h
+++ b/net/quic/quic_connection.h
@@ -223,11 +223,13 @@ class NET_EXPORT_PRIVATE QuicConnection
};
// Constructs a new QuicConnection for |connection_id| and |address|.
// |helper| and |writer| must outlive this connection.
QuicConnection(QuicConnectionId connection_id,
IPEndPoint address,
QuicConnectionHelperInterface* helper,
QuicPacketWriter* writer,
+ bool owns_writer,
bool is_server,
const QuicVersionVector& supported_versions);
virtual ~QuicConnection();
@@ -632,7 +634,8 @@ class NET_EXPORT_PRIVATE QuicConnection
QuicFramer framer_;
QuicConnectionHelperInterface* helper_; // Not owned.
- QuicPacketWriter* writer_; // Not owned.
+ QuicPacketWriter* writer_; // Owned or not depending on |owns_writer_|.
+ bool owns_writer_;
EncryptionLevel encryption_level_;
const QuicClock* clock_;
QuicRandom* random_generator_;
@@ -223,11 +223,13 @@ class NET_EXPORT_PRIVATE QuicConnection
};
// Constructs a new QuicConnection for |connection_id| and |address|.
- // |helper| and |writer| must outlive this connection.
+ // |helper| must outlive this connection, and if |owns_writer| is false, so
+ // must |writer|.
QuicConnection(QuicConnectionId connection_id,
IPEndPoint address,
« no previous file with comments | « no previous file | net/quic/quic_connection.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698